==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/ArtifactManifestPropertiesFormatArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.ArtifactManifestPropertiesFormatArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Artifact manifest properties.
 * @property artifacts The artifacts list.
 */
public data class ArtifactManifestPropertiesFormatArgs(
    public val artifacts: Output<List<ManifestArtifactFormatArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.ArtifactManifestPropertiesFormatArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridnetwork.inputs.ArtifactManifestPropertiesFormatArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.ArtifactManifestPropertiesFormatArgs.builder()
            .artifacts(
                artifacts?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ArtifactManifestPropertiesFormatArgs].
 */
@PulumiTagMarker
public class ArtifactManifestPropertiesFormatArgsBuilder internal constructor() {
    private var artifacts: Output<List<ManifestArtifactFormatArgs>>? = null

    /**
     * @param value The artifacts list.
     */
    @JvmName("bcclgbpkyndvuglr")
    public suspend fun artifacts(`value`: Output<List<ManifestArtifactFormatArgs>>) {
        this.artifacts = value
    }

    @JvmName("nwbwrghmsxlmeklt")
    public suspend fun artifacts(vararg values: Output<ManifestArtifactFormatArgs>) {
        this.artifacts = Output.all(values.asList())
    }

    /**
     * @param values The artifacts list.
     */
    @JvmName("wofjqkdtjqixgueh")
    public suspend fun artifacts(values: List<Output<ManifestArtifactFormatArgs>>) {
        this.artifacts = Output.all(values)
    }

    /**
     * @param value The artifacts list.
     */
    @JvmName("mvarcsqewuhpipot")
    public suspend fun artifacts(`value`: List<ManifestArtifactFormatArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.artifacts = mapped
    }

    /**
     * @param argument The artifacts list.
     */
    @JvmName("imvlvrfxqfeegwqd")
    public suspend
    fun artifacts(argument: List<suspend ManifestArtifactFormatArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ManifestArtifactFormatArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.artifacts = mapped
    }

    /**
     * @param argument The artifacts list.
     */
    @JvmName("ecjuokslfpogpbak")
    public suspend fun artifacts(
        vararg
        argument: suspend ManifestArtifactFormatArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ManifestArtifactFormatArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.artifacts = mapped
    }

    /**
     * @param argument The artifacts list.
     */
    @JvmName("vxpdburrsdhiieut")
    public suspend fun artifacts(argument: suspend ManifestArtifactFormatArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ManifestArtifactFormatArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.artifacts = mapped
    }

    /**
     * @param values The artifacts list.
     */
    @JvmName("efutrmnnnnscdtqt")
    public suspend fun artifacts(vararg values: ManifestArtifactFormatArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.artifacts = mapped
    }

    internal fun build(): ArtifactManifestPropertiesFormatArgs = ArtifactManifestPropertiesFormatArgs(
        artifacts = artifacts,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hybridnetwork/kotlin/inputs/ArtifactManifestPropertiesFormatArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridnetwork.kotlin.inputs

import com.pulumi.azurenative.hybridnetwork.inputs.ArtifactManifestPropertiesFormatArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Artifact manifest properties.
 * @property artifacts The artifacts list.
 */
public data class ArtifactManifestPropertiesFormatArgs(
    public val artifacts: Output<List<ManifestArtifactFormatArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridnetwork.inputs.ArtifactManifestPropertiesFormatArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridnetwork.inputs.ArtifactManifestPropertiesFormatArgs =
        com.pulumi.azurenative.hybridnetwork.inputs.ArtifactManifestPropertiesFormatArgs.builder()
            .artifacts(
                artifacts?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ArtifactManifestPropertiesFormatArgs].
 */
@PulumiTagMarker
public class ArtifactManifestPropertiesFormatArgsBuilder internal constructor() {
    private var artifacts: Output<List<ManifestArtifactFormatArgs>>? = null

    /**
     * @param value The artifacts list.
     */
    @JvmName("ehjnvxrnfmpencjj")
    public suspend fun artifacts(`value`: Output<List<ManifestArtifactFormatArgs>>) {
        this.artifacts = value
    }

    @JvmName("conknwettswcgexy")
    public suspend fun artifacts(vararg values: Output<ManifestArtifactFormatArgs>) {
        this.artifacts = Output.all(values.asList())
    }

    /**
     * @param values The artifacts list.
     */
    @JvmName("fqiqpwgqyacsfgyt")
    public suspend fun artifacts(values: List<Output<ManifestArtifactFormatArgs>>) {
        this.artifacts = Output.all(values)
    }

    /**
     * @param value The artifacts list.
     */
    @JvmName("oknmhghlcgfkspxm")
    public suspend fun artifacts(`value`: List<ManifestArtifactFormatArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.artifacts = mapped
    }

    /**
     * @param argument The artifacts list.
     */
    @JvmName("mrhvlrljoghlyfiw")
    public suspend
    fun artifacts(argument: List<suspend ManifestArtifactFormatArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ManifestArtifactFormatArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.artifacts = mapped
    }

    /**
     * @param argument The artifacts list.
     */
    @JvmName("cfgpluusyxirhtje")
    public suspend fun artifacts(
        vararg
        argument: suspend ManifestArtifactFormatArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ManifestArtifactFormatArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.artifacts = mapped
    }

    /**
     * @param argument The artifacts list.
     */
    @JvmName("drvqfafjxqfekfbm")
    public suspend fun artifacts(argument: suspend ManifestArtifactFormatArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ManifestArtifactFormatArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.artifacts = mapped
    }

    /**
     * @param values The artifacts list.
     */
    @JvmName("jpoxhtykhnrinquc")
    public suspend fun artifacts(vararg values: ManifestArtifactFormatArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.artifacts = mapped
    }

    internal fun build(): ArtifactManifestPropertiesFormatArgs = ArtifactManifestPropertiesFormatArgs(
        artifacts = artifacts,
    )
}
